@@ -97,7 +97,11 @@ def bind_method(**config):
                 del self.parameters[name]
 
                 self.path = self.path.replace(variable, value)
-            self.path = self.path + '.%s' % self.api.format
+
+            if self.api.format:
+                self.path = self.path + '.%s' % self.api.format
+            else:
+                self.path = self.path
 
         def _build_pagination_info(self, content_obj):
             """Extract pagination information in the desired format."""
@@ -130,7 +134,7 @@ def bind_method(**config):
                 if content_obj.get('code') == 420 or content_obj.get('code') == 429:
                     error_message = content_obj.get('error_message') or "Your client is making too many request per second"
                     raise InstagramAPIError(content_obj.get('code'), "Rate limited", error_message)
-                raise InstagramAPIError(content_obj.has_key('code'), content_obj.has_key('error_type'), content_obj.has_key('error_message'))
+                raise InstagramAPIError(content_obj.get('code'), content_obj.get('error_type'), content_obj.get('error_message'))
 
             api_responses = []
             status_code = content_obj['meta']['code']
@@ -162,7 +166,7 @@ def bind_method(**config):
         def _paginator_with_url(self, url, method="GET", body=None, headers=None):
             headers = headers or {}
             pages_read = 0
-            while url and pages_read < self.max_pages:
+            while url and (pages_read < self.max_pages or self.max_pages is None):
                 api_responses, url = self._do_api_request(url, method, body, headers)
                 pages_read += 1
                 yield api_responses, url
